import { Message, OmitPartialGroupDMChannel } from "discord.js";
import { SQLCommon } from "../storage/interfaces";
import { SQLResult } from "../storage/enumerations";

export async function doesMessageExist(db: SQLCommon, message: OmitPartialGroupDMChannel<Message<boolean>>) : Promise<boolean> {
    const queryResult: Object[] = await db.getAllParameterized(
        "SELECT * FROM messages WHERE message_snowflake = ?",
        [message.id]
    )

    return queryResult.length != 0
}

export async function insertMessage(db: SQLCommon, message: OmitPartialGroupDMChannel<Message<boolean>>) : Promise<SQLResult> {
    const alreadyExists: boolean = await doesMessageExist(db, message)

    if(alreadyExists) {
        return SQLResult.ALREADYEXISTS
    }

    try {
        await db.runParameterized(
            "INSERT INTO messages VALUES (?, ?, ?, ?, ?, ?)",
            [message.id, message.channel.id, message.author.id, 
                message.content, message.createdTimestamp, 0]
        )

        return SQLResult.CREATED
    } catch (err) {
        //TODO Winston should handle this
        console.log(err)
        return SQLResult.FAILED
    }
}